@@ -91,42 +91,6 @@ class Drive(NetBoxModel):
         return self.size - current_partition_allocated_space
 
 
-class MountedVolume(NetBoxModel):
-    mount_point = models.CharField(
-        max_length=255,
-    )
-    fs_type = models.ForeignKey(
-        Filesystem,
-        on_delete=models.CASCADE,
-        related_name='fs_mounted_volume',
-        verbose_name='Filesystem',
-    )
-    options = models.CharField(
-        max_length=255,
-        blank=True,
-    )
-    description = models.CharField(
-        max_length=255,
-        blank=True,
-    )
-
-    clone_fields = [
-        'mount_point',
-        'fs_type',
-        'options',
-        'description',
-    ]
-
-    def get_absolute_url(self):
-        return reverse('plugins:netbox_storage:mountedvolume', kwargs={'pk': self.pk})
-
-    def __str__(self):
-        return f'Filesystem Table Entry: mounted to {self.mount_point}'
-
-    class Meta:
-        ordering = ('mount_point', 'fs_type', 'options', 'description')
-
-
 class LinuxDevice(NetBoxModel):
     device = models.CharField(
         max_length=255,
@@ -311,11 +275,6 @@ class LogicalVolume(NetBoxModel):
     size = models.FloatField(
         verbose_name='Size (GB)'
     )
-    device = models.ForeignKey(
-        LinuxDevice,
-        on_delete=models.CASCADE,
-        related_name='device_logical_volume',
-    )
     description = models.CharField(
         max_length=255,
         blank=True,
@@ -325,7 +284,6 @@ class LogicalVolume(NetBoxModel):
         'vg',
         'lv_name',
         'size',
-        'device',
         'description',
     ]
 
@@ -388,3 +346,46 @@ class TemplateConfigurationDrive(NetBoxModel):
 
     def __str__(self):
         return f'Template Configuration of the Platform {self.platform}'
+
+
+class MountedVolume(NetBoxModel):
+    linux_device = models.ForeignKey(
+        LinuxDevice,
+        on_delete=models.CASCADE,
+        related_name='linux_device_mounted_volume',
+    )
+    mount_point = models.CharField(
+        max_length=255,
+    )
+    fs_type = models.ForeignKey(
+        Filesystem,
+        on_delete=models.CASCADE,
+        related_name='fs_mounted_volume',
+        verbose_name='Filesystem',
+    )
+    options = models.CharField(
+        max_length=255,
+        default='defaults',
+        blank=True,
+    )
+    description = models.CharField(
+        max_length=255,
+        blank=True,
+    )
+
+    clone_fields = [
+        'linux_device',
+        'mount_point',
+        'fs_type',
+        'options',
+        'description',
+    ]
+
+    def get_absolute_url(self):
+        return reverse('plugins:netbox_storage:mountedvolume', kwargs={'pk': self.pk})
+
+    def __str__(self):
+        return f'Filesystem Table Entry: mounted to {self.mount_point}'
+
+    class Meta:
+        ordering = ('linux_device', 'mount_point', 'fs_type', 'options', 'description')
